==> cscec5b-fjwz-impl-3.0.1-20221205.085819-29-sources.jar: com/ejianc/business/fjwz/bean/DisposeDetailEntity.java <==
package com.ejianc.business.fjwz.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 处置申请明细表
 * 
 * @author generator
 * 
 */
 @TableName("ejc_fjwz_dispose_detail")
public class DisposeDetailEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="dispose_id")
    private Long disposeId; // 处置申请单主键
    @TableField(value="material_type_id")
    private Long materialTypeId; // 物料分类id
    @TableField(value="material_type_name")
    private String materialTypeName; // 物料分类名称
    @TableField(value="material_id")
    private Long materialId; // 物料主键
    @TableField(value="material_name")
    private String materialName; // 物料名称
    @TableField(value="material_code")
    private String materialCode; // 物料编码
    @TableField(value="material_source_id")
    private String materialSourceId; // 物资来源主键
    @TableField(value="spec")
    private String spec; // 规格型号
    @TableField(value="unit_id")
    private String unitId; // 单位id
    @TableField(value="unit_name")
    private String unitName; // 单位名称
    @TableField(value="sum_num")
    private BigDecimal sumNum; // 累计进场数量
    @TableField(value="sum_loss_rate")
    private BigDecimal sumLossRate; // 总损耗率
    @TableField(value="sum_loss_num")
    private BigDecimal sumLossNum; // 累计损耗数量
    @TableField(value="num")
    private BigDecimal num; // 本次处置数量
    @TableField(value="loss_rate")
    private BigDecimal lossRate; // 本次损耗率
    @TableField(value="tax_mny")
    private BigDecimal taxMny; // 暂估金额
    @TableField(value="memo")
    private String memo; // 备注
    @TableField(value="source_type")
    private Integer sourceType; // 来源类型 0-在场材料，1-物资档案
    
    
    

    public Long getDisposeId() {
        return disposeId;
    }

    public void setDisposeId(Long disposeId) {
        this.disposeId = disposeId;
    }
    public Long getMaterialTypeId() {
        return materialTypeId;
    }

    public void setMaterialTypeId(Long materialTypeId) {
        this.materialTypeId = materialTypeId;
    }
    public String getMaterialTypeName() {
        return materialTypeName;
    }

    public void setMaterialTypeName(String materialTypeName) {
        this.materialTypeName = materialTypeName;
    }
    public Long getMaterialId() {
        return materialId;
    }

    public void setMaterialId(Long materialId) {
        this.materialId = materialId;
    }
    public String getMaterialName() {
        return materialName;
    }

    public void setMaterialName(String materialName) {
        this.materialName = materialName;
    }
    public String getMaterialCode() {
        return materialCode;
    }

    public void setMaterialCode(String materialCode) {
        this.materialCode = materialCode;
    }
    public String getMaterialSourceId() {
        return materialSourceId;
    }

    public void setMaterialSourceId(String materialSourceId) {
        this.materialSourceId = materialSourceId;
    }
    public String getSpec() {
        return spec;
    }

    public void setSpec(String spec) {
        this.spec = spec;
    }
    public String getUnitId() {
        return unitId;
    }

    public void setUnitId(String unitId) {
        this.unitId = unitId;
    }
    public String getUnitName() {
        return unitName;
    }

    public void setUnitName(String unitName) {
        this.unitName = unitName;
    }
    public BigDecimal getSumNum() {
        return sumNum;
    }

    public void setSumNum(BigDecimal sumNum) {
        this.sumNum = sumNum;
    }
    public BigDecimal getSumLossRate() {
        return sumLossRate;
    }

    public void setSumLossRate(BigDecimal sumLossRate) {
        this.sumLossRate = sumLossRate;
    }
    public BigDecimal getSumLossNum() {
        return sumLossNum;
    }

    public void setSumLossNum(BigDecimal sumLossNum) {
        this.sumLossNum = sumLossNum;
    }
    public BigDecimal getNum() {
        return num;
    }

    public void setNum(BigDecimal num) {
        this.num = num;
    }
    public BigDecimal getLossRate() {
        return lossRate;
    }

    public void setLossRate(BigDecimal lossRate) {
        this.lossRate = lossRate;
    }
    public BigDecimal getTaxMny() {
        return taxMny;
    }

    public void setTaxMny(BigDecimal taxMny) {
        this.taxMny = taxMny;
    }
    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }
    public Integer getSourceType() {
        return sourceType;
    }

    public void setSourceType(Integer sourceType) {
        this.sourceType = sourceType;
    }
    
}

==> cscec5b-fjwz-impl-3.0.1-20240124.105634-88-sources.jar: com/ejianc/business/fjwz/bean/DisposeDetailEntity.java <==
package com.ejianc.business.fjwz.bean;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;

import java.math.BigDecimal;

/**
 * 处置申请明细表
 *
 * @author generator
 *
 */
 @TableName("ejc_fjwz_dispose_detail")
public class DisposeDetailEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;

    @TableField(value="dispose_id")
    private Long disposeId; // 处置申请单主键
    @TableField(value="material_type_id")
    private Long materialTypeId; // 物料分类id
    @TableField(value="material_type_name")
    private String materialTypeName; // 物料分类名称
    @TableField(value="material_id")
    private Long materialId; // 物料主键
    @TableField(value="material_name")
    private String materialName; // 物料名称
    @TableField(value="material_code")
    private String materialCode; // 物料编码
    @TableField(value="material_source_id")
    private String materialSourceId; // 物资来源主键
    @TableField(value="spec")
    private String spec; // 规格型号
    @TableField(value="unit_id")
    private String unitId; // 单位id
    @TableField(value="unit_name")
    private String unitName; // 单位名称
    @TableField(value="sum_num")
    private BigDecimal sumNum; // 累计进场数量
    @TableField(value="sum_loss_rate")
    private BigDecimal sumLossRate; // 总损耗率
    @TableField(value="sum_loss_num")
    private BigDecimal sumLossNum; // 累计损耗数量
    @TableField(value="num")
    private BigDecimal num; // 本次处置数量
    @TableField(value="loss_rate")
    private BigDecimal lossRate; // 本次损耗率
    @TableField(value="tax_mny")
    private BigDecimal taxMny; // 暂估金额
    @TableField(value="memo")
    private String memo; // 备注
    @TableField(value="source_type")
    private Integer sourceType; // 来源类型 0-在场材料，1-物资档案
    @TableField(value="sum_mny")
    private BigDecimal sumMny; // 累计进场金额
    @TableField(value="sum_tax_mny")
    private BigDecimal sumTaxMny; // 累计进场金额(含税)
    @TableField(value="dispose_mny")
    private BigDecimal disposeMny; // 本次处置原值
    @TableField(value="dispose_tax_mny")
    private BigDecimal disposeTaxMny; // 本次处置原值(含税)





    public Long getDisposeId() {
        return disposeId;
    }

    public void setDisposeId(Long disposeId) {
        this.disposeId = disposeId;
    }
    public Long getMaterialTypeId() {
        return materialTypeId;
    }

    public void setMaterialTypeId(Long materialTypeId) {
        this.materialTypeId = materialTypeId;
    }
    public String getMaterialTypeName() {
        return materialTypeName;
    }

    public void setMaterialTypeName(String materialTypeName) {
        this.materialTypeName = materialTypeName;
    }
    public Long getMaterialId() {
        return materialId;
    }

    public void setMaterialId(Long materialId) {
        this.materialId = materialId;
    }
    public String getMaterialName() {
        return materialName;
    }

    public void setMaterialName(String materialName) {
        this.materialName = materialName;
    }
    public String getMaterialCode() {
        return materialCode;
    }

    public void setMaterialCode(String materialCode) {
        this.materialCode = materialCode;
    }
    public String getMaterialSourceId() {
        return materialSourceId;
    }

    public void setMaterialSourceId(String materialSourceId) {
        this.materialSourceId = materialSourceId;
    }
    public String getSpec() {
        return spec;
    }

    public void setSpec(String spec) {
        this.spec = spec;
    }
    public String getUnitId() {
        return unitId;
    }

    public void setUnitId(String unitId) {
        this.unitId = unitId;
    }
    public String getUnitName() {
        return unitName;
    }

    public void setUnitName(String unitName) {
        this.unitName = unitName;
    }
    public BigDecimal getSumNum() {
        return sumNum;
    }

    public void setSumNum(BigDecimal sumNum) {
        this.sumNum = sumNum;
    }
    public BigDecimal getSumLossRate() {
        return sumLossRate;
    }

    public void setSumLossRate(BigDecimal sumLossRate) {
        this.sumLossRate = sumLossRate;
    }
    public BigDecimal getSumLossNum() {
        return sumLossNum;
    }

    public void setSumLossNum(BigDecimal sumLossNum) {
        this.sumLossNum = sumLossNum;
    }
    public BigDecimal getNum() {
        return num;
    }

    public void setNum(BigDecimal num) {
        this.num = num;
    }
    public BigDecimal getLossRate() {
        return lossRate;
    }

    public void setLossRate(BigDecimal lossRate) {
        this.lossRate = lossRate;
    }
    public BigDecimal getTaxMny() {
        return taxMny;
    }

    public void setTaxMny(BigDecimal taxMny) {
        this.taxMny = taxMny;
    }
    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }
    public Integer getSourceType() {
        return sourceType;
    }

    public void setSourceType(Integer sourceType) {
        this.sourceType = sourceType;
    }

    public BigDecimal getSumMny() {
        return sumMny;
    }

    public void setSumMny(BigDecimal sumMny) {
        this.sumMny = sumMny;
    }

    public BigDecimal getSumTaxMny() {
        return sumTaxMny;
    }

    public void setSumTaxMny(BigDecimal sumTaxMny) {
        this.sumTaxMny = sumTaxMny;
    }

    public BigDecimal getDisposeMny() {
        return disposeMny;
    }

    public void setDisposeMny(BigDecimal disposeMny) {
        this.disposeMny = disposeMny;
    }

    public BigDecimal getDisposeTaxMny() {
        return disposeTaxMny;
    }

    public void setDisposeTaxMny(BigDecimal disposeTaxMny) {
        this.disposeTaxMny = disposeTaxMny;
    }
}
